package com.example.cookbook.repository;


import com.example.cookbook.dbConfig.DB;
import com.example.cookbook.model.Komentar;
import org.springframework.stereotype.Repository;

import java.sql.*;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Repository
public class KomentariRepository {

    public List<Komentar> findAllByRecId(Long recId) throws SQLException {
        Connection connection = DB.getConnection();

        String query = "select k.kom_data, k.telefon, k.rec_id, k.ocena, k.text, korisnici.kor_ime, korisnici.prezime\n" +
                "from komentari k\n" +
                "    left join korisnici on k.telefon = korisnici.telefon\n" +
                "where rec_id = ?;";

        PreparedStatement prepStm = connection.prepareStatement(query);
        prepStm.setLong(1, recId);

        ResultSet result = prepStm.executeQuery();
        List<Komentar> komentari = new ArrayList<>();

        while (result.next()){
            Komentar komentar = new Komentar();
            komentar.setKomData(result.getObject("kom_data", LocalDateTime.class));
            komentar.setTelefon(result.getString("telefon"));
            komentar.setRecId(result.getLong("rec_id"));
            komentar.setOcena(result.getInt("ocena"));
            komentar.setText(result.getString("text"));
            komentar.setImePrezime(result.getString("kor_ime") + " " + result.getString("prezime"));
            komentari.add(komentar);
        }

        result.close();
        prepStm.close();
        DB.closeConnection();

        return komentari;
    }

    public void save(Komentar komentar) throws SQLException {
        Connection connection = DB.getConnection();

        String query = "insert into komentari (kom_data, telefon, rec_id, ocena, text) values \n" +
                "        (?, ?, ?, ?, ?);";

        PreparedStatement prepStm = connection.prepareStatement(query);
        prepStm.setObject(1, komentar.getKomData());
        prepStm.setString(2, komentar.getTelefon());
        prepStm.setLong(3, komentar.getRecId());
        prepStm.setInt(4, komentar.getOcena());
        prepStm.setString(5, komentar.getText());

        prepStm.executeUpdate();

        prepStm.close();
        DB.closeConnection();
    }
}
